"""
Django application configuration for the Encrypted Object Search Engine.
"""

from django.apps import AppConfig


class DjangoDecryptedSearchConfig(AppConfig):
    """
    Primary AppConfig class for the django_eose module.
    """

    default_auto_field = "django.db.models.BigAutoField"
    name = "django_eose"
    verbose_name = "Django Encrypted Object Search Engine"
